/** \file
	\brief Niskopoziomowe funkcje obsugi pamici EEPROM 25AA640
	\author Tomasz Ostrowski
*/
#include <p18cxxx.h>
#include "io_cfg.h"
#include <spi.h>

#define EE_WRSR     0x01
#define EE_WRITE    0x02
#define EE_READ     0x03
#define EE_WRDI     0x04
#define EE_RDSR     0x05	///< komenda odczytu rejestru statusu
#define EE_WREN     0x06	///< komenda odblokowania zapisu

/** \brief Inicjalizacja interfejsu SPI dla wsppracy z EEPROM */
void EESpiInit(void)
{
    EE_CSN = 1;								// deselect
}

/** \brief Sprawdzenie czy pami nie jest w tym momencie zajta */
unsigned char EEStatus(void)
{
    unsigned char b;
    EE_CSN = 0;
    WriteSPI(EE_RDSR);
    b = ReadSPI();//SpiReadWrite(0);
    EE_CSN = 1;
    return b;
}

/** \brief Odczyt bajtu
	\param adres
*/
unsigned char EERead(unsigned int addr)
{
    unsigned char b;

    while ((EEStatus() & 0x01) != 0x00)     // Wait if busy
        ;
    EE_CSN = 0;
    WriteSPI(EE_READ);
    WriteSPI(addr >> 8);
    WriteSPI(addr & 0xff);
    b = ReadSPI();//SpiReadWrite(0);
    EE_CSN = 1;
    return b;
}

/** \brief Zapis bajtu
	\param adres
	\param bajt danych
*/
void EEWrite(unsigned int addr, unsigned char b)
{
    while((EEStatus() & 0x01) != 0x00);      // Wait if busy
    EE_CSN = 0;
    WriteSPI(EE_WREN);
    EE_CSN = 1;
    EE_CSN = 0;
    WriteSPI(EE_WRITE);
    WriteSPI(addr >> 8);
    WriteSPI(addr & 0xff);
    WriteSPI(b);
    EE_CSN = 1;									//deselect
}
