/*********************************************************************
 *
 *                Microchip USB C18 Firmware Version 1.0
 *
 *********************************************************************
 * FileName:        io_cfg.h
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the Company) for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       7/21/04     Original.
 * Tomasz Ostrowski     1/05/06     changed definitions for SPTS
 ********************************************************************/

#ifndef IO_CFG_H
#define IO_CFG_H

/** I N C L U D E S *************************************************/
#include "autofiles\usbcfg.h"

/** T R I S *********************************************************/
#define INPUT_PIN           1
#define OUTPUT_PIN          0

/** U S B ***********************************************************/
#define tris_usb_bus_sense  TRISCbits.TRISC1    // Input

//defined in usbcfg.h
//undefine USE_USB_BUS_SENSE_IO if you don't want to use
//PORTA1 as USB_BUS_SENSE pin
#if defined(USE_USB_BUS_SENSE_IO)
#define usb_bus_sense       PORTCbits.RC1
#else
#define usb_bus_sense       1
#endif

#define tris_self_power     TRISAbits.TRISA2    // Input

//defined in usbcfg.h
//undefine USE_SELF_POWER_SENSE_IO if you don't want to use
//PORTA2 as SELF_POWER_SENSE pin
#if defined(USE_SELF_POWER_SENSE_IO)
#define self_power          PORTAbits.RA2
#else
#define self_power          1
#endif


#define mLED_1_On()         mLED_1 = 1;
#define mLED_2_On()         mLED_2 = 1;
#define mLED_3_On()         mLED_3 = 1;
#define mLED_4_On()         mLED_4 = 1;
#define mLED_5_On()         mLED_5 = 1;
#define mLED_6_On()         mLED_6 = 1;

#define mLED_1_Off()        mLED_1 = 0;
#define mLED_2_Off()        mLED_2 = 0;
#define mLED_3_Off()        mLED_3 = 0;
#define mLED_4_Off()        mLED_4 = 0;
#define mLED_5_Off()        mLED_5 = 0;
#define mLED_6_Off()        mLED_6 = 0;

#define mLED_1_Toggle()     mLED_1 = !mLED_1;
#define mLED_2_Toggle()     mLED_2 = !mLED_2;
#define mLED_3_Toggle()     mLED_3 = !mLED_3;
#define mLED_4_Toggle()     mLED_4 = !mLED_4;
#define mLED_5_Toggle()     mLED_5 = !mLED_5;
#define mLED_6_Toggle()     mLED_6 = !mLED_6;


//inicjalizacja linii portow
#define mInitPA()           LATA &= 0x00; TRISA &= 0x00;    //init PORTA
//#define mInitPA()           LATA &= 0x00; TRISA &= 0x03;    //init PORTA
#define mLED_1              LATAbits.LATA0
#define mLED_2              LATAbits.LATA1
#define mLED_3              LATAbits.LATA2
#define mLED_4              LATAbits.LATA3
#define mLED_5              LATAbits.LATA4
#define mLED_6              LATAbits.LATA5
//#define mInitAllLEDs()      LATA &= 0b11100111; TRISA &= 0b11100111;


#define mInitPB()           LATB &= 0b00000101; TRISB &= 0b00000101;    //init PORTB         
#define BEEPER              LATBbits.LATB7
#define TX_EN_On()          LATBbits.LATB3 = 1
#define TX_EN_Off()         LATBbits.LATB3 = 0
#define EE_CSN_On()         LATBbits.LATB6 = 1	//linia CSN pamici EEPROM
#define EE_CSN_Off()        LATBbits.LATB6 = 0
#define EE_CSN				LATBbits.LATB6
#define TXEN                LATBbits.LATB3

//RB5 - TRX_CE
#define TRX_CE              LATBbits.LATB5
//RB4 - CSN
#define CSN_On()            LATBbits.LATB4 = 1
#define CSN_Off()           LATBbits.LATB4 = 0
#define EECSN_On()          LATBbits.LATB6 = 1
#define EECSN_Off()         LATBbits.LATB6 = 0

#define CSN                 LATBbits.LATB4
//RB2 - DR
#define DR                  PORTBbits.RB2

//#define TrgRst_On()         LATBbits.LATB2 = 1
//#define TrgRst_Off()        LATBbits.LATB2 = 0
//#define TrgRst_HighZ()      TRISB |= 0b00000100
//#define TrgRst_Normal()     TRISB &= 0b11111011

#define mInitPC()           LATC &= 0b00000010; TRISC &= 0b00000010;    //init PORTC
#define PWR_UP_On()         LATCbits.LATC6 = 1
#define PWR_UP_Off()        LATCbits.LATC6 = 0


/** S W I T C H *****************************************************/
#define mInitSwitch1()      TRISCbits.TRISC2=1;
#define sw1                 PORTCbits.RC2


#endif //IO_CFG_H
